# nludb

Python client library for NLUDB: the database for Natural Langauge Understanding.

## Description

NLUDB is a cloud-hosted database that helps developers get work done with natural language content.

